---
title: <span class="badge builder"></span> XYDimensionConfig
---
# <span class="badge builder"></span> XYDimensionConfig

## Constructor

```python
XYDimensionConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> xychart.XYDimensionConfig
```

### <span class="badge object-method"></span> exclude

```python
def exclude(exclude: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> frame

```python
def frame(frame: int) -> typing.Self
```

### <span class="badge object-method"></span> x

```python
def x(x: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [XYDimensionConfig](./object-XYDimensionConfig.md)
